==> bitcoin_0.13.1.orig.tar.gz: bitcoin-0.13.1/src/qt/locale/bitcoin_hi_IN.ts <==
<TS language="hi_IN" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>नया पता लिखिए !</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>चुनिन्दा पते को सिस्टम क्लिपबोर्ड पर कापी करे !</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;मिटाए !!</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>पहचान शब्द/अक्षर डालिए !</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>नया पहचान शब्द/अक्षर डालिए !</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>दोबारा नया पहचान शब्द/अक्षर डालिए !</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Synchronizing with network...</source>
        <translation>नेटवर्क से समकालिक (मिल) रहा है ...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;विवरण</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>वॉलेट का सामानया विवरण दिखाए !</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp; लेन-देन
</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>देखिए पुराने लेन-देन के विवरण !</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>बाहर जायें</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>अप्लिकेशन से बाहर निकलना !</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;विकल्प</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>&amp;बैकप वॉलेट</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>पहचान शब्द/अक्षर जो वॉलेट एनक्रिपशन के लिए इस्तेमाल किया है उसे बदलिए!</translation>
    </message>
    <message>
        <source>Bitcoin</source>
        <translation>बीटकोइन</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>वॉलेट</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;फाइल</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;सेट्टिंग्स</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;मदद</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>टैबस टूलबार</translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 पीछे</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>भूल</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>चेतावनी</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>जानकारी</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>नवीनतम</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>भेजी ट्रांजक्शन</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>प्राप्त हुई ट्रांजक्शन</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>वॉलेट एन्क्रिप्टेड है तथा अभी लॉक्ड नहीं है</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>वॉलेट एन्क्रिप्टेड है तथा अभी लॉक्ड है</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>राशि :</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>राशि</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>taareek</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>पक्का</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>पता एडिट करना</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;लेबल</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;पता</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>संस्करण</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>खपत :</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Error</source>
        <translation>भूल</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>विकल्प</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>वॉलेट</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;ओके</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;कैन्सल</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>फार्म</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>राशि</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>लागू नही
</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>लागू नही
</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>जानकारी</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation>राशि :</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>लेबल:</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Copy &amp;Address</source>
        <translation>&amp;पता कॉपी करे</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>सिक्के भेजें|</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>राशि :</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>एक साथ कई प्राप्तकर्ताओं को भेजें</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>बाकी रकम :</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>भेजने की पुष्टि करें</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>अमाउंट:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>प्राप्तकर्ता:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>लेबल:</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt-A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Clipboard से एड्रेस paste करें</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt-P</translation>
    </message>
    <message>
        <source>Pay To:</source>
        <translation>प्राप्तकर्ता:</translation>
    </message>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Alt+A</source>
        <translation>Alt-A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Clipboard से एड्रेस paste करें</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt-P</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>हस्ताक्षर</translation>
    </message>
    </context>
<context>
    <name>SplashScreen</name>
    <message>
        <source>[testnet]</source>
        <translation>[टेस्टनेट]</translation>
    </message>
</context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation> ये खिड़की आपको लेन-देन का विस्तृत विवरण देगी !</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    </context>
<context>
    <name>TransactionView</name>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Options:</source>
        <translation>विकल्प:</translation>
    </message>
    <message>
        <source>Specify data directory</source>
        <translation>डेटा डायरेक्टरी बताएं </translation>
    </message>
    <message>
        <source>Run in the background as a daemon and accept commands</source>
        <translation>बैकग्राउंड में डेमॉन बन कर रन करे तथा कमांड्स स्वीकार करें </translation>
    </message>
    <message>
        <source>Verifying blocks...</source>
        <translation>ब्लॉक्स जाँचे जा रहा है...</translation>
    </message>
    <message>
        <source>Verifying wallet...</source>
        <translation>वॉलेट जाँचा जा रहा है...</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>जानकारी</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>चेतावनी</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>पता पुस्तक आ रही है...</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>ब्लॉक इंडेक्स आ रहा है...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>वॉलेट आ रहा है...</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>रि-स्केनी-इंग...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>लोड हो गया|</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>भूल</translation>
    </message>
</context>
</TS>

==> bitcoin-0.15.1.tar.gz: bitcoin-0.15.1/src/qt/locale/bitcoin_hi_IN.ts <==
<TS language="hi_IN" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>पते या लेबल को संपादित करने के लिए राइट-क्लिक करें</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>नया पता लिखिए !</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;NEW</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>चुनिन्दा पते को सिस्टम क्लिपबोर्ड पर कापी करे !</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>सूची से वर्तमान में चयनित पता हटाएं</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;मिटाए !!</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>पहचान शब्द/अक्षर डालिए !</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>नया पहचान शब्द/अक्षर डालिए !</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>दोबारा नया पहचान शब्द/अक्षर डालिए !</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Synchronizing with network...</source>
        <translation>नेटवर्क से समकालिक (मिल) रहा है ...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;विवरण</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>वॉलेट का सामानया विवरण दिखाए !</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp; लेन-देन
</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>देखिए पुराने लेन-देन के विवरण !</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>बाहर जायें</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>अप्लिकेशन से बाहर निकलना !</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;विकल्प</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>&amp;बैकप वॉलेट</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>पहचान शब्द/अक्षर जो वॉलेट एनक्रिपशन के लिए इस्तेमाल किया है उसे बदलिए!</translation>
    </message>
    <message>
        <source>Bitcoin</source>
        <translation>बीटकोइन</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>वॉलेट</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;फाइल</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;सेट्टिंग्स</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;मदद</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>टैबस टूलबार</translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 पीछे</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>भूल</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>चेतावनी</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>जानकारी</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>नवीनतम</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>भेजी ट्रांजक्शन</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>प्राप्त हुई ट्रांजक्शन</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>वॉलेट एन्क्रिप्टेड है तथा अभी लॉक्ड नहीं है</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>वॉलेट एन्क्रिप्टेड है तथा अभी लॉक्ड है</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>राशि :</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>राशि</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>taareek</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>पक्का</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>पता एडिट करना</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;लेबल</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;पता</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>संस्करण</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>खपत :</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Error</source>
        <translation>भूल</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>फार्म</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>विकल्प</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>वॉलेट</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;ओके</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;कैन्सल</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>फार्म</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>राशि</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>लागू नही
</translation>
    </message>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>लागू नही
</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>जानकारी</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation>राशि :</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>लेबल:</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Copy &amp;Address</source>
        <translation>&amp;पता कॉपी करे</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>सिक्के भेजें|</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>राशि :</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>एक साथ कई प्राप्तकर्ताओं को भेजें</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>बाकी रकम :</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>भेजने की पुष्टि करें</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>अमाउंट:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>प्राप्तकर्ता:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>लेबल:</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt-A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Clipboard से एड्रेस paste करें</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt-P</translation>
    </message>
    <message>
        <source>Pay To:</source>
        <translation>प्राप्तकर्ता:</translation>
    </message>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Alt+A</source>
        <translation>Alt-A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Clipboard से एड्रेस paste करें</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt-P</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>हस्ताक्षर</translation>
    </message>
    </context>
<context>
    <name>SplashScreen</name>
    <message>
        <source>[testnet]</source>
        <translation>[टेस्टनेट]</translation>
    </message>
</context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation> ये खिड़की आपको लेन-देन का विस्तृत विवरण देगी !</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    </context>
<context>
    <name>TransactionView</name>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Options:</source>
        <translation>विकल्प:</translation>
    </message>
    <message>
        <source>Specify data directory</source>
        <translation>डेटा डायरेक्टरी बताएं </translation>
    </message>
    <message>
        <source>Run in the background as a daemon and accept commands</source>
        <translation>बैकग्राउंड में डेमॉन बन कर रन करे तथा कमांड्स स्वीकार करें </translation>
    </message>
    <message>
        <source>Verifying blocks...</source>
        <translation>ब्लॉक्स जाँचे जा रहा है...</translation>
    </message>
    <message>
        <source>Verifying wallet...</source>
        <translation>वॉलेट जाँचा जा रहा है...</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>जानकारी</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>चेतावनी</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>पता पुस्तक आ रही है...</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>ब्लॉक इंडेक्स आ रहा है...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>वॉलेट आ रहा है...</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>रि-स्केनी-इंग...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>लोड हो गया|</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>भूल</translation>
    </message>
</context>
</TS>
